<template>
  <view class="list">
    <z-paging
      ref="pagingRef"
      v-model="cardList"
      :fixed="false"
      :auto-show-back-to-top="true"
      @query="getList"
    >
      <template #top>
        <CardTitle title="盘具领用" :hideAction="true" :full="false" @action="addReport" />
      </template>
      <wd-card v-for="(item, index) in cardList" :key="index" type="rectangle" custom-class="round">
        <template #title>
          <view class="flex justify-between">
            <view>
              <wd-icon name="a-rootlist" color="#0D867F"></wd-icon>
              <text class="text-[#252525] ml-2 font-medium">{{ item.diskMaterial }}</text>
            </view>
            <view class="text-[#A8A8A8]" @click="toEdit(item.id)">编辑</view>
          </view>
        </template>
        <ProductionCard :data="cardAttr" :value="item" color="#0D867F" />
      </wd-card>
    </z-paging>
    <wd-popup v-model="dialog.visible" position="bottom" custom-class="yl-popup">
      <view class="action px-3">
        <wd-button type="text" @click="cancel">取消</wd-button>
        <wd-button type="text" @click="submit">确定</wd-button>
      </view>
      <PlateForm ref="plateFormRef" @refresh="reloadList" />
    </wd-popup>
    <wd-toast />
  </view>
</template>

<script setup lang="ts">
import CardTitle from "@/components/card-title/index.vue";
import ProductionCard from "../../../components/ProductionCard.vue";
import { useToast } from "wot-design-uni";
import PlateForm from "./form.vue";
import { onLoad } from "@dcloudio/uni-app";
import ManageApi from "@/api/product/manage";
import zPaging from "@/components/z-paging/z-paging.vue";

const paramsId = ref();
const pagingRef = ref();
const plateFormRef = ref();
const toast = useToast();
const dialog = reactive({
  visible: false,
});
const cardList = ref<any[]>([]);

const cardAttr = ref<any[]>([
  {
    label: "尺寸",
    prop: "model",
  },
  {
    label: "重量",
    prop: "weight",
    unit: "kg",
  },
  {
    label: "数量",
    prop: "amount",
  },
  {},
  {
    label: "厂家",
    prop: "supplier",
    span: 14,
  },
]);

const toEdit = (id: number) => {
  uni.navigateTo({
    url: `/pages/production/twist/receive/plate/edit?id=${id}`,
  });
};

const addReport = () => {
  dialog.visible = true;
};

const submit = async () => {
  toast.show("提交");
  dialog.visible = !(await plateFormRef.value.submit());
};

const cancel = () => {
  toast.show("取消");
  dialog.visible = false;
};

const reloadList = () => {
  pagingRef.value.refresh();
};

const getList = async () => {
  const { code, data } = await ManageApi.getStrandedWireDish({
    wireId: paramsId.value,
    type: "盘具",
  });
  if (code == 200) {
    pagingRef.value.complete(data);
  }
};
onLoad((options: any) => {
  paramsId.value = options.id;
});
</script>

<style lang="scss" scoped>
.list {
  height: calc(100vh - 120px);
  padding: 12px;
  background: #f3f9f8;

  :deep() {
    .round {
      border-radius: 4px;
    }
  }
}

.action {
  display: flex;
  justify-content: space-between;
}
</style>
